# AR Drivers
Python package for communicating with AR equipment using VISA.

## Requirements
* Python 3 (https://www.python.org)
    * Developed and tested with Python 3.10
* VISA (http://www.ni.com/visa/)
* PyVISA (https://pypi.org/project/PyVISA/)
    * Will install automatically with the ardrivers package

## Installation
The preferred method of installation is to use pip. Extract the ardrivers folder (which contains `setup.py`)
and run the following command from within this folder. (Note the final `.` which specifies the current directory):

> pip install .

If this is being run on Windows and the python scripts directory hasn't been added to the PATH, pip may not be found.
In this case, use the following to invoke pip as a python module:

> py -m pip install .

PyVISA will be installed as a dependency. To install it manually for any reason, use:

> pip install pyvisa


# Supported Equipment

## Amplifiers
The amplifier module works by supplying the AR_Amp class init method with a model:

```python
amp = AR_Amp('175S1G4A')
```

If `model` is not provided, the driver will default to the newest command set. If your amplifier
uses an LCD touch panel, you should be safe to leave out the model.

To get a list of supported models that don't use the LCD touch panel, use:

```python
AR_Amp.all_models()
```

A simple example to power on an amplifier connected with GPIB, set the gain to 100, and turn RF on:

```python
from ardrivers import aramplifier

amp = aramplifier.AR_Amp()
amp.initialize('GPIB0::1::INSTR')
amp.power(1)
amp.set_rf_gain(100)
amp.rf_output(1)
amp.close()
```
    
Note that internal communication in the amplifier can sometimes take some time, especially after power on.
It is a good idea to use `time.sleep()` after certain methods if you notice the methods following are not
being executed correctly.

Because this driver is universal, your amplifier may not support all methods. If you call an unsupported method,
it will simply do nothing. Refer to your manual to determine which remote commands are supported, and also to
see tables to help you decode the responses from `read_state()` and `read_fault()`.


## System Controllers
The system controller module contains two classes: AR_SC1000 and AR_SC2000.
Both inherit from the _AR_SC base class, but this should not be used outside of the package. Initialize(), reset(), set_switch(), query_switch(), and close() are
inherited from the base class and can be used by both derived SC classes.

#### SC1000
The SC1000 class has all the basic functionality for controlling switches and outputs, and reading their current state.
Power needs to be enabled with the power() function before any switching can be done. 

A simple example to set a switch and an open collector:

```python
from ardrivers import arsystemcontroller

sc = arsystemcontroller.AR_SC1000()
sc.initialize('GPIB0::1::INSTR')
sc.power(1)
sc.set_switch(1, 2)
sc.set_open_collector(1,1)
sc.close()
``` 

#### SC2000
The SC2000 class provides more functionality for the newer model system controller including controlling multiple SCX modules, 
setting multiple switches/open drains/TTL lines in a single function call for faster performance, and saving/loading
multiple user configurations.

Functions that perform multiple operations have a flag called `wait_for_complete` which is true by default and will poll
the state of the SC2000 to determine when switching is complete.

A simple example to set the first four switches with a list of tuples and save the state as a user configuration:

```python
from ardrivers import arsystemcontroller

sc = arsystemcontroller.AR_SC2000()
sc.initialize('GPIB0::1::INSTR')
sc.set_switches([(1,1), (2,2), (3,3), (4,4)])
sc.save_configuration('USER1')
sc.close()
``` 


## Field Probes
The field probe module contains three classes. AR_FieldProbe is used to communicate with FL series probes through an FI7000/FI8000
laser interface box. AR_FieldMonitor is used with the FM7004 and FM7004A field monitors. AR_FieldAnalyzer is used with
the FA series of field analyzers.

A simple example to take a reading using AR_FieldProbe. Note that read_data() returns a dictionary. Several of the methods
in this module work the same way. The doc strings for those methods explain the keys available when a dictionary is returned:

```python
from ardrivers import arfieldprobe

fp = arfieldprobe.AR_FieldProbe()
fp.initialize('GPIB0::1::INSTR')
data = fp.read_data()
fp.close()
```

# Examples
The examples folder contains an example script for each type of equipment. The VISA address and other variables are set
at the beginning of each example script. Change these to match the device you are communicating with.